@@ -1,6 +1,7 @@
 import sys
 import os
 
+from csv import QUOTE_NONE
 from datetime import datetime
 
 from .parser import parser
@@ -25,8 +26,9 @@ def main(args):
     """
     options = parser.parse_args(args)
 
-    model = load(options.model_file, options.missing_values,
-                 options.split_views, subview_sep=options.subview_sep)
+    model = load(options.model_file, options.data_files,
+                 options.missing_values, options.split_views,
+                 subview_sep=options.subview_sep)
 
     if not options.run:
         print("\nFinished!")
@@ -44,7 +46,7 @@ def main(args):
     sys.exit()
 
 
-def load(model_file, missing_values, split_views, **kwargs):
+def load(model_file, data_files, missing_values, split_views, **kwargs):
     """
     Translate and load model file.
 
@@ -53,6 +55,18 @@ def load(model_file, missing_values, split_views, **kwargs):
     model_file: str
         Vensim, Xmile or PySD model file.
 
+    data_files: list
+        If given the list of files where the necessary data to run the model
+        is given.
+
+    missing_values : str ("warning", "error", "ignore", "keep")
+        What to do with missing values. If "warning" (default)
+        shows a warning message and interpolates the values.
+        If "raise" raises an error. If "ignore" interpolates
+        the values without showing anything. If "keep" it will keep
+        the missing values, this option may cause the integration to
+        fail, but it may be used to check the quality of the data.
+
     split_views: bool (optional)
         If True, the sketch is parsed to detect model elements in each
         model view, and then translate each view in a separate python
@@ -74,14 +88,17 @@ def load(model_file, missing_values, split_views, **kwargs):
     if model_file.lower().endswith(".mdl"):
         print("\nTranslating model file...\n")
         return pysd.read_vensim(model_file, initialize=False,
+                                data_files=data_files,
                                 missing_values=missing_values,
                                 split_views=split_views, **kwargs)
     elif model_file.lower().endswith(".xmile"):
         print("\nTranslating model file...\n")
         return pysd.read_xmile(model_file, initialize=False,
+                               data_files=data_files,
                                missing_values=missing_values)
     else:
         return pysd.load(model_file, initialize=False,
+                         data_files=data_files,
                          missing_values=missing_values)
 
 
@@ -147,6 +164,8 @@ def save(output, options):
     else:
         sep = ","
 
-    output.to_csv(output_file, sep, index_label="Time")
+    # QUOTE_NONE used to print the csv/tab files af vensim does with special
+    # characterse, e.g.: "my-var"[Dimension]
+    output.to_csv(output_file, sep, index_label="Time", quoting=QUOTE_NONE)
 
     print(f"Data saved in '{output_file}'")
